@@ -178,7 +178,7 @@ module Test
       #   refute(false)    # => pass
       #   refute(nil)      # => pass
       #
-      # @example Fialure patterns
+      # @example Failure patterns
       #   refute(true)     # => failure
       #   refute("string") # => failure
       #
@@ -635,7 +635,6 @@ EOT
               raise
             end
           end
-          nil
         end
       end
 
@@ -2170,19 +2169,45 @@ EOT
           expected_exceptions.each do |exception_type|
             if exception_type.instance_of?(Module)
               exception_modules << exception_type
-            elsif exception_type.is_a?(Exception)
+            elsif exception_object?(exception_type)
               exception_objects << exception_type
-            else
-              @test_case.__send__(:assert,
-                                  Exception >= exception_type,
-                                  "Should expect a class of exception, " +
-                                  "#{exception_type}")
+            elsif exception_class?(exception_type)
               exception_classes << exception_type
+            else
+              full_message =
+                @test_case.__send__(:build_message,
+                                    nil,
+                                    "<?> must be " +
+                                    "a subclass of Exception, " +
+                                    "an object of Exception subclasses " +
+                                    "or a Module",
+                                    exception_type)
+              @test_case.flunk(full_message)
             end
           end
           [exception_classes, exception_modules, exception_objects]
         end
 
+        def exception_object?(exception_type)
+          return true if exception_type.is_a?(Exception)
+
+          if Object.const_defined?(:Java)
+            return true if exception_type.is_a?(Java::JavaLang::Throwable)
+          end
+
+          false
+        end
+
+        def exception_class?(exception_type)
+          return true if exception_type <= Exception
+
+          if Object.const_defined?(:Java)
+            return true if exception_type <= Java::JavaLang::Throwable
+          end
+
+          false
+        end
+
         def expected_class?(actual_exception, equality)
           @expected_classes.any? do |expected_class|
             actual_exception.__send__(equality, expected_class)
